@@ -1,6 +1,7 @@
 import os
 import time
 import glob
+from pathlib import Path
 import re
 import logging
 import importlib
@@ -32,12 +33,15 @@ class BatchProcessor:
         self.last_status_time = None
         self.callables = {}
         self.entry_name = "batch_filter_entrypoint"
-        self.db = Database(self.config)
+        if self.config.get("db-hostname", "skip") == "skip":
+            logger.warning("Skipping database initialization")
+        else:
+            self.db = Database(self.config)
 
     def verify(self):
-        modules=self.list_modules()
-        ok=[]
-        failed=[]
+        modules = self.list_modules()
+        ok = []
+        failed = []
         for (name, error) in modules:
             if error:
                 failed.append((name, error))
@@ -48,7 +52,7 @@ class BatchProcessor:
             for name in ok:
                 logger.info(f" + '{name}'")
         if failed:
-            message=""
+            message = ""
             logger.info("Failed modules:")
             for (name, error) in failed:
                 logger.error(f" + '{name}': {error}")
@@ -56,7 +60,6 @@ class BatchProcessor:
             return False, message
         return True, ""
 
-
     def load_module_by_filepath(self, module_name, module_filepath):
         module = None
         failure = None
@@ -86,31 +89,48 @@ class BatchProcessor:
         return module, failure
 
     def get_item_types(self):
-        module_filepath = os.path.join(self.config.get("batch-filter-root", "/dev/null"), "*.py")
-        # logger.info(f"Looking for types in {module_filepath}")
-        ret = []
-        for path in glob.glob(module_filepath):
-            name = os.path.basename(os.path.splitext(path)[0])
-            if not name.startswith("__"):
-                ret.append(name)
-                # logger.info(f" + {path} -> {name}")
+        module_root_raw = self.config.get("batch-filter-root", "/tmp/inexistant")
+        module_root_object = Path(module_root_raw).resolve(strict=False)
+        module_root = module_root_object.as_posix()
+        if not module_root:
+            logger.warning("Module root was not set")
+        if not os.path.exists(module_root):
+            logger.warning(f"Module root '{module_root}' did not exist")
+        logger.info(f"Looking for types in '{module_root}':")
+        ret = {}
+        for path_object in module_root_object.rglob("*.py"):
+            path_object = path_object.resolve(strict=False)
+            path = path_object.as_posix()
+            if path_object.name.startswith("__"):
+                logger.warning(f"Skipping invalid path {path}")
+                continue
+            if not path.startswith(module_root):
+                logger.warning(f"Skipping invalid path {path}")
+                continue
+            path_difference = path[len(module_root) + 1 :]
+            name = Path(path_difference).with_suffix("").as_posix()
+            ret[name] = path
+            logger.info(f"  Found {name} (from {path})")
         return ret
 
     def list_modules(self):
-        module_root_dir=self.config.get("batch-filter-root", "/tmp/inexistant")
-        ret=[]
-        failure=None
-        if not module_root_dir:
-            ret.append(("module_root_dir", f"Module root was not set"))
-        elif not os.path.exists(module_root_dir):
-            ret.append(("module_root_dir", f"Module root '{module_root_dir}' did not exist"))
+        module_root_raw = self.config.get("batch-filter-root", "/tmp/inexistant")
+        module_root_object = Path(module_root_raw).resolve(strict=False)
+        module_root = module_root_object.as_posix()
+
+        ret = []
+        failure = None
+        if not module_root:
+            ret.append(("module_root", f"Module root was not set"))
+        elif not os.path.exists(module_root):
+            ret.append(("module_root", f"Module root '{module_root}' did not exist"))
         else:
-            module_glob = os.path.join(module_root_dir, "**/*.py")
-            files=glob.glob(module_glob, recursive = True)
-            for module_filepath in files:
+            files_objects = module_root_object.rglob("*.py")
+            for file_object in files_objects:
+                module_filepath = file_object.as_posix()
                 if not module_filepath:
                     continue
-                if os.path.basename(module_filepath).startswith("__"):
+                if file_object.name.startswith("__"):
                     continue
                 if fk.utils.file_contains_str(module_filepath, self.entry_name):
                     try:
@@ -129,7 +149,7 @@ class BatchProcessor:
                         failure = f"Import of module '{module_filepath}' had errors and was skipped ({e})"
                 else:
                     failure = f"No entrypoint found in filter module {module_filepath}"
-                #logger.warn(f"Appending stat: {module_filepath}:{failure}")
+                # logger.warn(f"Appending stat: {module_filepath}:{failure}")
                 ret.append((module_filepath, failure))
         return ret
 
